@@ -118,6 +118,21 @@ open_request_logger (GPdfURIInput *in, const char *uri, gpointer user_data)
 }
 #endif
 
+static void
+set_window_icon_default (void)
+{
+	GdkPixbuf *pixbuf;
+
+	pixbuf = gdk_pixbuf_new_from_file (GNOMEICONDIR "/gnome-pdf.png", NULL);
+
+	if (pixbuf == NULL)
+		return;
+
+	gtk_window_set_default_icon (pixbuf);
+
+	g_object_unref (pixbuf);
+}
+
 int
 main (int argc, char **argv)
 {
@@ -140,6 +155,8 @@ main (int argc, char **argv)
 	if (bonobo_ui_init ("GNOME PDF Viewer", VERSION, &argc, argv) == FALSE)
 		g_error (_("Could not initialize Bonobo!\n"));
 
+	set_window_icon_default ();
+
 	client = gnome_master_client ();
 	
 	g_value_init (&value, G_TYPE_POINTER);
