@@ -194,8 +194,7 @@ gpdf_links_canvas_layer_class_init (GPdfLinksCanvasLayerClass *klass)
 			"links",
 			_("Links"),
 			_("Links"),
-			(GParamFlags)(G_PARAM_WRITABLE
-				      | G_PARAM_CONSTRUCT_ONLY)));
+			(GParamFlags)(G_PARAM_WRITABLE)));
 
 	gpdf_links_canvas_layer_signals [LINK_CLICKED] =
 		g_signal_new ("link_clicked",
